/*
 * Agua KWin client configuration module
 *
 * Copyright (C) 2002 Craig Drummond <craig@kde.org>
 *
 * Based on the Keramik configuration module,
 *     Copyright (c) 2002 Fredrik Hglund <fredrik@kde.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the license, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
 
#include <kglobal.h>
#include <klocale.h>

#include <qcheckbox.h>

#include "aguaconfig.h"
#include "aguaconfig.moc"
#include "aguaconfigui.h"

extern "C"
{
	QObject* allocate_config( KConfig* conf, QWidget* parent )
	{
		return ( new AguaConfig( conf, parent ) );
	}
}


/* NOTE: 
 * 'conf' 	is a pointer to the kwindecoration modules open kwin config,
 *			and is by default set to the "Style" group.
 *
 * 'parent'	is the parent of the QObject, which is a VBox inside the
 *			Configure tab in kwindecoration
 */

AguaConfig::AguaConfig( KConfig* conf, QWidget* parent )
	: QObject( parent )
{
	KGlobal::locale()->insertCatalogue("kwin_agua_config");
	c = new KConfig( "kwinaguarc" );
	
	ui = new AguaConfigUI( parent );
	connect( ui->showAppIcons,     SIGNAL(clicked()), SIGNAL(changed()) );
	connect( ui->smallCaptions,    SIGNAL(clicked()), SIGNAL(changed()) );
	connect( ui->largeGrabBars,    SIGNAL(clicked()), SIGNAL(changed()) );
	connect( ui->useShadowedText,  SIGNAL(clicked()), SIGNAL(changed()) );
    connect( ui->useColoredButtons, SIGNAL(clicked()), SIGNAL(changed()) );

	load( conf );
	ui->show();
}


AguaConfig::~AguaConfig()
{
	delete ui;
	delete c;
}


// Loads the configurable options from the kwinrc config file
// It is passed the open config from kwindecoration to improve efficiency
void AguaConfig::load( KConfig* )
{
	c->setGroup("General");
	ui->showAppIcons->setChecked( c->readBoolEntry("ShowAppIcons", true) );
	ui->smallCaptions->setChecked( c->readBoolEntry("SmallCaptionBubbles", true) );
	ui->largeGrabBars->setChecked( c->readBoolEntry("LargeGrabBars", false) );
	ui->useShadowedText->setChecked( c->readBoolEntry("UseShadowedText", false) );
    ui->useColoredButtons->setChecked( c->readBoolEntry("UseColoredButtons", true) );
}


// Saves the configurable options to the kwinrc config file
void AguaConfig::save( KConfig* )
{
	c->setGroup( "General" );
	c->writeEntry( "ShowAppIcons", ui->showAppIcons->isChecked() );
	c->writeEntry( "SmallCaptionBubbles", ui->smallCaptions->isChecked() );
	c->writeEntry( "LargeGrabBars", ui->largeGrabBars->isChecked() );
	c->writeEntry( "UseShadowedText", ui->useShadowedText->isChecked() );
    c->writeEntry( "UseColoredButtons", ui->useColoredButtons->isChecked() );
	c->sync();
}


// Sets UI widget defaults which must correspond to style defaults
void AguaConfig::defaults()
{
	ui->showAppIcons->setChecked( true );
	ui->smallCaptions->setChecked( true );
	ui->largeGrabBars->setChecked( false );
	ui->useShadowedText->setChecked( false );
    ui->useColoredButtons->setChecked( true );
	
	emit changed();
}

// vim: set noet ts=4 sw=4:
